@@ -15,6 +15,10 @@ logger = logging.getLogger(__name__)
 FORBID = False
 ALLOW = True
 
+_POLICIES = {
+    FORBID: "FORBID",
+    ALLOW: "ALLOW"
+}
 
 class FrontDoorConfig:
     defaults = dict(
@@ -24,18 +28,20 @@ class FrontDoorConfig:
         COOKIE_PATTERN=None,
         DEFAULT_POLICY=FORBID,
         ENABLED=False,  # FrontDoor enable/disable
-        ERROR_CODE=404,
+        ERROR_CODE=404,  # status code if access denied
         FORBIDDEN_PATHS=[],  # url paths regex list always denied
         HEADER=None,  # special header name without HTTP- prefix
-        REDIR_URL="",
+        REDIR_URL="",  # HttpResponseRedirect(REDIR_URL) if access denied
         ROUTER="front_door.router.DefaultRouter",
         RULES=[
-            "front_door.rules.forbidden_path",
-            "front_door.rules.allowed_ip",
-            "front_door.rules.internal_ip",
-            "front_door.rules.allowed_path",
-            "front_door.rules.special_header",
-            "front_door.rules.cookie_value",
+            "front_door.rules.internal_ip",  # grant access to settings.INTERNAL_IPS
+            "front_door.rules.forbidden_path",  # DENY access to FORBIDDEN_PATHS
+            "front_door.rules.allowed_ip",  # grant access to FORBIDDEN_PATHS
+            "front_door.rules.allowed_path",  # grant access to ALLOWED_PATHS
+            "front_door.rules.special_header",  # grant access if request has Header[HEADER] == TOKEN
+            "front_door.rules.has_header",  # grant access if request has HEADER
+            "front_door.rules.cookie_value",  # grant access if request.COOKIES[COOKIE_NAME]
+            "front_door.rules.cookie_exists",  # grant access ir COOKIE_NAME in request.COOKIES
         ],
         TOKEN=None,  # custom header value
     )
@@ -66,6 +72,10 @@ class FrontDoorConfig:
     def DEFAULT_POLICY(self):
         return parse_policy(self._get("DEFAULT_POLICY"))
 
+    @cached_property
+    def DEFAULT_POLICY_LABEL(self):
+        return _POLICIES[parse_policy(self._get("DEFAULT_POLICY"))]
+
     @cached_property
     def COOKIE_PATTERN(self):
         try:
