@@ -3,12 +3,10 @@ import logging
 from .conf import (config, front_door_is_active, get_front_door_allowed_ips,
                    get_front_door_forbidden_paths, get_front_door_internal_ips,
                    get_front_door_whitelisted_paths)
-from .exception import FrontDoorClosed
+from .exception import FrontDoorAccessDenied
 from .utils import get_client_ip
 
 logger = logging.getLogger(__name__)
-logger_allow = logging.getLogger(f"{__name__}.allow")
-logger_denied = logging.getLogger(f"{__name__}.denied")
 
 
 def allowed_ip(request, ip, path, **kwargs):
@@ -24,13 +22,18 @@ def special_header(request, ip, path, **kwargs):
         return request.headers.get(config.HEADER) == config.TOKEN
 
 
+def has_header(request, ip, path, **kwargs):
+    if config.HEADER:
+        return config.HEADER in request.headers
+
+
 def allowed_path(request, ip, path, **kwargs):
     return path in get_front_door_whitelisted_paths()
 
 
 def forbidden_path(request, ip, path, **kwargs):
     if path in get_front_door_forbidden_paths():
-        raise FrontDoorClosed
+        raise FrontDoorAccessDenied
 
 
 def cookie_exists(request, ip, path, **kwargs):
@@ -49,25 +52,22 @@ def cookie_value(request, ip, path, **kwargs):
 
 def front_door_check_access(request):
     if not front_door_is_active():
-        logger.debug("FrontDoor disabled")
         access_allowed = True
     else:
         access_allowed = config.DEFAULT_POLICY
         ip = get_client_ip(request)
         path = request.path
-
+        extra = {"ip": ip,
+                 "path": path}
         for check in config.allows:
             try:
                 if check(request, ip, path):
-                    logger_allow.info(f"FrontDoor access ALLOWED by '{check.__name__}()' to {path}")
+                    logger.debug(f"{check.__name__}() PASS", extra=extra)
                     access_allowed = True
                     break
                 else:
-                    logger_denied.debug(f"FrontDoor access NOT GRANTED by '{check.__name__}()' to {path}")
-            except FrontDoorClosed:
-                logger_denied.debug(f"FrontDoor access FORBIDDEN by '{check.__name__}()' to {path}")
+                    logger.debug(f"{check.__name__}() FAIL", extra=extra)
+            except FrontDoorAccessDenied:
+                logger.debug(f"{check.__name__}() DENY", extra=extra)
                 return False
-        if not access_allowed:
-            logger_denied.error(f"FrontDoor access DENIED to {path}", ip=ip, path=path)
-
     return access_allowed
