@@ -32,4 +32,4 @@ def parse_bool(value):
 
 
 def parse_policy(value):
-    return value in [True, "True", "true", "T", "1", 1, "y", "Y", "allow", "open"]
+    return parse_bool(value) or (str(value).lower() in ["allow", "open"])
